@@ -4,6 +4,8 @@ import numpy as np
 from plotnine import *
 from PIL import Image
 
+from ATACFragQC import __version__
+
 class ArgumentList:
     file_bam = ''
     file_ref = ''
@@ -21,7 +23,7 @@ def bedScan(args):
     print("Processing the reference...")
     ref = pd.read_table(args.file_ref, comment='#', header=None)
     ref.columns = ['seq_id', 'source', 'type', 'start', 'end', 'score', 'strand', 'phase', 'attributes']
-    ref = ref[(ref['type'] == 'transcript') & (ref['strand'] != '-') & ref['attributes'].str.match('.*gene_type \"protein_coding\".*') & ref['seq_id'].str.match('chr[0-9XY]+')]
+    ref = ref[(ref['type'] == 'transcript') & (ref['strand'] != '-') & ref['seq_id'].str.match('^chr[0-9XY]+$') & (ref['start'] > 1000)]
     ref = ref[['seq_id', 'strand', 'start', 'end']].sort_values(by=['seq_id', 'start', 'strand'])
     ref = ref.drop_duplicates(subset=['seq_id', 'start', 'strand'], keep='first')
     ref.loc[ref['strand'] == '+', 'start'] -= 1000
@@ -44,7 +46,7 @@ def bedScan(args):
     len_count = pd.DataFrame({'V1': list(range(1, 501)), 'V2': len_count[1:]})
     chr_count = pd.DataFrame({'V1': list(chr_count.keys()), 'V2': list(chr_count.values())})
     chr_count = chr_count[chr_count['V1'].str.match('chr.*')]
-    chr_list = list(map(lambda x: int(x.replace('chr', '')), list(chr_count.loc[chr_count['V1'].str.match('chr[0-9]+'), 'V1'])))
+    chr_list = list(map(lambda x: int(x.replace('chr', '')), list(chr_count.loc[chr_count['V1'].str.match('^chr[0-9]+$'), 'V1'])))
     chr_list.sort()
     chr_list += ['X', 'Y', 'M']
     chr_list = list(map(lambda x: 'chr'+str(x), chr_list))
@@ -106,7 +108,8 @@ def main():
         ['help', 'output', 'input=', 'reference=', 'quality=', 'length='])
     arguments = ArgumentList()
     help_flag = False
-    help_info = 'Usage:\nATACFragQC [options] -i <input.bam> -r <reference.gtf>\nArguments:\n'\
+    help_info = 'ATACFragQC - Version: '+__version__+'\n'\
+        +'Usage:\nATACFragQC [options] -i <input.bam> -r <reference.gtf>\nArguments:\n'\
         +'-i <file>\tA aligned & deduped BAM file\n'\
         +'-f <file>\tGTF genome annotation\n'\
         +'-o \t\tThe table of results would be saved if -o was set (default: False)\n'\
